\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{kjmath}[2015/12/19 v1.1]
\LoadClass[12pt,a4paper,twoside]{amsart}

% Submission option turns on marking of overfull lines
\DeclareOption{submission}
{\overfullrule=1mm}
\DeclareOption{final}
{}

% Default is submission, to turn of marking set to final version
\ProcessOptions


\RequirePackage[T1]{fontenc}
\RequirePackage{letltxmacro}
\RequirePackage{cite}
\RequirePackage{lmodern}
\RequirePackage[stretch=10,shrink=10]{microtype}
\RequirePackage[colorlinks=false, pdfborder={0 0 0}]{hyperref}
\usepackage{ifthen}
\usepackage{xstring}

% Define the margin widths
\setlength\textheight{8.39in}
\setlength\textwidth{6.0in}
\setlength\oddsidemargin{0.3in}
\setlength\evensidemargin{0.3in}
\setlength\topmargin{0.0in}
\setlength\headsep{0.35in}
\setlength\headheight{0.17in}
\setlength\topmargin{0.38in}
\setlength\topskip{0.14in}
\setlength\footskip{0.42in}



% Define the cyrillic Dj and dj characters
% REPLACED BY THE \RequirePackage[T1]{fontenc} above
%\ProvideTextCommand{\DJ}{OT1}{\raisebox{0.3ex}{-}\kern-0.4em D}
%\def\dj{\hbox{d\kern-.33em\raise.80ex\hbox{-} \raise-.80ex\hbox{\kern-.40em}}}


% Redefine the first level list symbol
\renewcommand{\theenumi}{\alph{enumi}}
\renewcommand{\labelenumi}{(\theenumi)}
% Redefine the second level list symbol
\renewcommand{\theenumii}{\roman{enumii}}
\renewcommand{\labelenumii}{\theenumii}

\newcommand{\Dj}{\DJ}

% Define the mathematical environments

\theoremstyle{plain}

\newtheorem{theorem}{Theorem}[section]
\newtheorem{proposition}{Proposition}[section]
\newtheorem{lemma}{Lemma}[section]
\newtheorem{corollary}{Corollary}[section]


\theoremstyle{definition}

\newtheorem{definition}{Definition}[section]


\theoremstyle{remark}

\newtheorem{remark}{Remark}[section]
\newtheorem{example}{Example}[section]


\DeclareMathOperator{\Span}{Span}
\DeclareMathOperator{\diag}{diag}
\DeclareMathOperator{\sgn}{sgn}
\DeclareMathOperator{\Si}{Si}
\DeclareMathOperator{\supp}{supp}
\DeclareMathOperator{\Co}{Co}
\DeclareMathOperator{\Pc}{Pc}
\DeclareMathOperator{\res}{Res}


% Set the equation numbering preference
\numberwithin{equation}{section}


% Force cross references to be normal font
%\newcommand{\reffont}{}%
\AtBeginDocument{%
  \LetLtxMacro\oldref\ref%
  \renewcommand{\ref}[1]{%
  {\normalfont\oldref{#1}}}%
}


% Force citations to be normal font
\renewcommand{\@cite}[2]{\citeleft{\normalfont #1}\ifthenelse{\not\equal{#2}{}}{{\normalfont , #2}}{}\citeright}
\renewcommand\citeleft{{\normalfont [}}
\renewcommand\citeright{{\normalfont ]}}

% Create the KJM title page
\def\kjmvolume#1{\def\@kjmvolume{#1}}
\def\kjmnumber#1{\def\@kjmnumber{#1}}
\def\kjmyear#1{\def\@kjmyear{#1}}
\def\kjmstpage#1{\def\@kjmstpage{#1}}
\def\kjmendpage#1{\def\@kjmendpage{#1}}

\newcommand*{\IsInteger}[3]{%
    \IfStrEq{#1}{}{%
        % blank string
    }{%
        \IfInteger{#1}{#2}{#3}%
    }%
}%
    
\def\makekjmtitle{%
\IsInteger{\@kjmstpage}{\setcounter{page}{\@kjmstpage}}{}
\noindent
{\small\textsc {Kragujevac Journal of Mathematics}}
\newline
\noindent{\small\textsc {Volume %
\@kjmvolume
(%
\@kjmnumber
) (%
\@kjmyear
), Pages %
\@kjmstpage%
--%
\@kjmendpage%
.}}
\vspace{35mm}
\baselineskip=0.20in
\maketitle
}


% Define acknowldgement section
\newenvironment{acknowledgements}{\subsection*{Acknowledgements.}}{\par\null}